@@ -138,6 +138,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_lambda
@@ -178,6 +180,9 @@ class EmailSubscription(
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
         :param filter_policy: The filter policy. Default: - all messages are delivered
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EmailSubscription.__init__)
+            check_type(argname="argument email_address", value=email_address, expected_type=type_hints["email_address"])
         props = EmailSubscriptionProps(
             json=json, dead_letter_queue=dead_letter_queue, filter_policy=filter_policy
         )
@@ -193,6 +198,9 @@ class EmailSubscription(
 
         :param _topic: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EmailSubscription.bind)
+            check_type(argname="argument _topic", value=_topic, expected_type=type_hints["_topic"])
         return typing.cast(aws_cdk.aws_sns.TopicSubscriptionConfig, jsii.invoke(self, "bind", [_topic]))
 
 
@@ -248,6 +256,9 @@ class LambdaSubscription(
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
         :param filter_policy: The filter policy. Default: - all messages are delivered
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaSubscription.__init__)
+            check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         props = LambdaSubscriptionProps(
             dead_letter_queue=dead_letter_queue, filter_policy=filter_policy
         )
@@ -263,6 +274,9 @@ class LambdaSubscription(
 
         :param topic: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaSubscription.bind)
+            check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
         return typing.cast(aws_cdk.aws_sns.TopicSubscriptionConfig, jsii.invoke(self, "bind", [topic]))
 
 
@@ -294,6 +308,9 @@ class SmsSubscription(
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
         :param filter_policy: The filter policy. Default: - all messages are delivered
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SmsSubscription.__init__)
+            check_type(argname="argument phone_number", value=phone_number, expected_type=type_hints["phone_number"])
         props = SmsSubscriptionProps(
             dead_letter_queue=dead_letter_queue, filter_policy=filter_policy
         )
@@ -309,6 +326,9 @@ class SmsSubscription(
 
         :param _topic: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SmsSubscription.bind)
+            check_type(argname="argument _topic", value=_topic, expected_type=type_hints["_topic"])
         return typing.cast(aws_cdk.aws_sns.TopicSubscriptionConfig, jsii.invoke(self, "bind", [_topic]))
 
 
@@ -344,6 +364,9 @@ class SqsSubscription(
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
         :param filter_policy: The filter policy. Default: - all messages are delivered
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SqsSubscription.__init__)
+            check_type(argname="argument queue", value=queue, expected_type=type_hints["queue"])
         props = SqsSubscriptionProps(
             raw_message_delivery=raw_message_delivery,
             dead_letter_queue=dead_letter_queue,
@@ -361,6 +384,9 @@ class SqsSubscription(
 
         :param topic: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SqsSubscription.bind)
+            check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
         return typing.cast(aws_cdk.aws_sns.TopicSubscriptionConfig, jsii.invoke(self, "bind", [topic]))
 
 
@@ -404,6 +430,10 @@ class SubscriptionProps:
                 }
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SubscriptionProps.__init__)
+            check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
+            check_type(argname="argument filter_policy", value=filter_policy, expected_type=type_hints["filter_policy"])
         self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
@@ -479,6 +509,9 @@ class UrlSubscription(
         :param dead_letter_queue: Queue to be used as dead letter queue. If not passed no dead letter queue is enabled. Default: - No dead letter queue enabled.
         :param filter_policy: The filter policy. Default: - all messages are delivered
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(UrlSubscription.__init__)
+            check_type(argname="argument url", value=url, expected_type=type_hints["url"])
         props = UrlSubscriptionProps(
             protocol=protocol,
             raw_message_delivery=raw_message_delivery,
@@ -497,6 +530,9 @@ class UrlSubscription(
 
         :param _topic: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(UrlSubscription.bind)
+            check_type(argname="argument _topic", value=_topic, expected_type=type_hints["_topic"])
         return typing.cast(aws_cdk.aws_sns.TopicSubscriptionConfig, jsii.invoke(self, "bind", [_topic]))
 
 
@@ -548,6 +584,12 @@ class UrlSubscriptionProps(SubscriptionProps):
                 raw_message_delivery=False
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(UrlSubscriptionProps.__init__)
+            check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
+            check_type(argname="argument filter_policy", value=filter_policy, expected_type=type_hints["filter_policy"])
+            check_type(argname="argument protocol", value=protocol, expected_type=type_hints["protocol"])
+            check_type(argname="argument raw_message_delivery", value=raw_message_delivery, expected_type=type_hints["raw_message_delivery"])
         self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
@@ -656,6 +698,11 @@ class EmailSubscriptionProps(SubscriptionProps):
                 json=False
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EmailSubscriptionProps.__init__)
+            check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
+            check_type(argname="argument filter_policy", value=filter_policy, expected_type=type_hints["filter_policy"])
+            check_type(argname="argument json", value=json, expected_type=type_hints["json"])
         self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
@@ -759,6 +806,10 @@ class LambdaSubscriptionProps(SubscriptionProps):
                 }
             ))
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaSubscriptionProps.__init__)
+            check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
+            check_type(argname="argument filter_policy", value=filter_policy, expected_type=type_hints["filter_policy"])
         self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
@@ -839,6 +890,10 @@ class SmsSubscriptionProps(SubscriptionProps):
                 }
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SmsSubscriptionProps.__init__)
+            check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
+            check_type(argname="argument filter_policy", value=filter_policy, expected_type=type_hints["filter_policy"])
         self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
@@ -923,6 +978,11 @@ class SqsSubscriptionProps(SubscriptionProps):
                 raw_message_delivery=False
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SqsSubscriptionProps.__init__)
+            check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
+            check_type(argname="argument filter_policy", value=filter_policy, expected_type=type_hints["filter_policy"])
+            check_type(argname="argument raw_message_delivery", value=raw_message_delivery, expected_type=type_hints["raw_message_delivery"])
         self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
